Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(727)

Unified Diff: ui/accessibility/platform/ax_platform_node_delegate.h

Issue 2119413004: a11y: Exclude children of nested keyboard accessible controls from a11y tree. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix compile error and final test in NativeWidgetMacTest. Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/accessibility/platform/ax_platform_node_delegate.h
diff --git a/ui/accessibility/platform/ax_platform_node_delegate.h b/ui/accessibility/platform/ax_platform_node_delegate.h
index 1e27f3f00a09f5d3754b07db46ada6405b934882..96663fbe4f2e24b014b127ef1c659bcb2f20e7ae 100644
--- a/ui/accessibility/platform/ax_platform_node_delegate.h
+++ b/ui/accessibility/platform/ax_platform_node_delegate.h
@@ -42,10 +42,10 @@ class AX_EXPORT AXPlatformNodeDelegate {
// be a native accessible object implemented by another class.
virtual gfx::NativeViewAccessible GetParent() = 0;
// Get the number of children of this node.
virtual int GetChildCount() = 0;
// Get the child of a node given a 0-based index.
virtual gfx::NativeViewAccessible ChildAtIndex(int index) = 0;
// Get the offset to convert local coordinates to screen global coordinates.
@@ -68,6 +68,9 @@ class AX_EXPORT AXPlatformNodeDelegate {
// has focus.
virtual gfx::NativeViewAccessible GetFocus() = 0;
+ // Whether this element should be ignored by the accessibility client.
+ virtual bool IsIgnored() = 0;
+
//
// Events.
//
@@ -42,10 +42,10 @@ class AX_EXPORT AXPlatformNodeDelegate {
// be a native accessible object implemented by another class.
virtual gfx::NativeViewAccessible GetParent() = 0;
- // Get the number of children of this node.
+ // Get the number of children of this node, excluding ignored children.
virtual int GetChildCount() = 0;
@@ -42,10 +42,10 @@ class AX_EXPORT AXPlatformNodeDelegate {
virtual int GetChildCount() = 0;
- // Get the child of a node given a 0-based index.
+ // Get the child of a node given a 0-based index, excluding ignored children.
virtual gfx::NativeViewAccessible ChildAtIndex(int index) = 0;
// Get the offset to convert local coordinates to screen global coordinates.
« no previous file with comments | « no previous file | ui/accessibility/platform/ax_platform_node_mac.mm » ('j') | ui/accessibility/platform/ax_platform_node_mac.mm » ('J')

Powered by Google App Engine
This is Rietveld 408576698